"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel, UnrecognizedStr
from openrouter.utils import get_discriminator, validate_const, validate_open_enum
import pydantic
from pydantic import Discriminator, Tag
from pydantic.functional_validators import AfterValidator, PlainValidator
from typing import List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class Schema17ResponseHealingTypedDict(TypedDict):
    id: Literal["response-healing"]
    enabled: NotRequired[bool]


class Schema17ResponseHealing(BaseModel):
    ID: Annotated[
        Annotated[
            Literal["response-healing"],
            AfterValidator(validate_const("response-healing")),
        ],
        pydantic.Field(alias="id"),
    ] = "response-healing"

    enabled: Optional[bool] = None


PdfEngine = Union[
    Literal[
        "mistral-ocr",
        "pdf-text",
        "native",
    ],
    UnrecognizedStr,
]


class PdfTypedDict(TypedDict):
    engine: NotRequired[PdfEngine]


class Pdf(BaseModel):
    engine: Annotated[
        Optional[PdfEngine], PlainValidator(validate_open_enum(False))
    ] = None


class Schema17FileParserTypedDict(TypedDict):
    id: Literal["file-parser"]
    enabled: NotRequired[bool]
    pdf: NotRequired[PdfTypedDict]


class Schema17FileParser(BaseModel):
    ID: Annotated[
        Annotated[
            Literal["file-parser"], AfterValidator(validate_const("file-parser"))
        ],
        pydantic.Field(alias="id"),
    ] = "file-parser"

    enabled: Optional[bool] = None

    pdf: Optional[Pdf] = None


Engine = Union[
    Literal[
        "native",
        "exa",
    ],
    UnrecognizedStr,
]


class Schema17WebTypedDict(TypedDict):
    id: Literal["web"]
    enabled: NotRequired[bool]
    max_results: NotRequired[float]
    search_prompt: NotRequired[str]
    engine: NotRequired[Engine]


class Schema17Web(BaseModel):
    ID: Annotated[
        Annotated[Literal["web"], AfterValidator(validate_const("web"))],
        pydantic.Field(alias="id"),
    ] = "web"

    enabled: Optional[bool] = None

    max_results: Optional[float] = None

    search_prompt: Optional[str] = None

    engine: Annotated[Optional[Engine], PlainValidator(validate_open_enum(False))] = (
        None
    )


class Schema17ModerationTypedDict(TypedDict):
    id: Literal["moderation"]


class Schema17Moderation(BaseModel):
    ID: Annotated[
        Annotated[Literal["moderation"], AfterValidator(validate_const("moderation"))],
        pydantic.Field(alias="id"),
    ] = "moderation"


class Schema17AutoRouterTypedDict(TypedDict):
    id: Literal["auto-router"]
    enabled: NotRequired[bool]
    allowed_models: NotRequired[List[str]]


class Schema17AutoRouter(BaseModel):
    ID: Annotated[
        Annotated[
            Literal["auto-router"], AfterValidator(validate_const("auto-router"))
        ],
        pydantic.Field(alias="id"),
    ] = "auto-router"

    enabled: Optional[bool] = None

    allowed_models: Optional[List[str]] = None


Schema17TypedDict = TypeAliasType(
    "Schema17TypedDict",
    Union[
        Schema17ModerationTypedDict,
        Schema17ResponseHealingTypedDict,
        Schema17AutoRouterTypedDict,
        Schema17FileParserTypedDict,
        Schema17WebTypedDict,
    ],
)


Schema17 = Annotated[
    Union[
        Annotated[Schema17AutoRouter, Tag("auto-router")],
        Annotated[Schema17Moderation, Tag("moderation")],
        Annotated[Schema17Web, Tag("web")],
        Annotated[Schema17FileParser, Tag("file-parser")],
        Annotated[Schema17ResponseHealing, Tag("response-healing")],
    ],
    Discriminator(lambda m: get_discriminator(m, "id", "id")),
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatmessagecontentitemtext import (
    ChatMessageContentItemText,
    ChatMessageContentItemTextTypedDict,
)
from openrouter.types import BaseModel
from openrouter.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


DeveloperMessageContentTypedDict = TypeAliasType(
    "DeveloperMessageContentTypedDict",
    Union[str, List[ChatMessageContentItemTextTypedDict]],
)


DeveloperMessageContent = TypeAliasType(
    "DeveloperMessageContent", Union[str, List[ChatMessageContentItemText]]
)


class DeveloperMessageTypedDict(TypedDict):
    content: DeveloperMessageContentTypedDict
    role: Literal["developer"]
    name: NotRequired[str]


class DeveloperMessage(BaseModel):
    content: DeveloperMessageContent

    ROLE: Annotated[
        Annotated[Literal["developer"], AfterValidator(validate_const("developer"))],
        pydantic.Field(alias="role"),
    ] = "developer"

    name: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from openrouter.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    validate_const,
)
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DeleteKeysGlobalsTypedDict(TypedDict):
    http_referer: NotRequired[str]
    r"""The app identifier should be your app's URL and is used as the primary identifier for rankings.
    This is used to track API usage per application.

    """
    x_title: NotRequired[str]
    r"""The app display name allows you to customize how your app appears in OpenRouter's dashboard.

    """


class DeleteKeysGlobals(BaseModel):
    http_referer: Annotated[
        Optional[str],
        pydantic.Field(alias="HTTP-Referer"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""The app identifier should be your app's URL and is used as the primary identifier for rankings.
    This is used to track API usage per application.

    """

    x_title: Annotated[
        Optional[str],
        pydantic.Field(alias="X-Title"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""The app display name allows you to customize how your app appears in OpenRouter's dashboard.

    """


class DeleteKeysRequestTypedDict(TypedDict):
    hash: str
    r"""The hash identifier of the API key to delete"""
    http_referer: NotRequired[str]
    r"""The app identifier should be your app's URL and is used as the primary identifier for rankings.
    This is used to track API usage per application.

    """
    x_title: NotRequired[str]
    r"""The app display name allows you to customize how your app appears in OpenRouter's dashboard.

    """


class DeleteKeysRequest(BaseModel):
    hash: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The hash identifier of the API key to delete"""

    http_referer: Annotated[
        Optional[str],
        pydantic.Field(alias="HTTP-Referer"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""The app identifier should be your app's URL and is used as the primary identifier for rankings.
    This is used to track API usage per application.

    """

    x_title: Annotated[
        Optional[str],
        pydantic.Field(alias="X-Title"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""The app display name allows you to customize how your app appears in OpenRouter's dashboard.

    """


class DeleteKeysResponseTypedDict(TypedDict):
    r"""API key deleted successfully"""

    deleted: Literal[True]
    r"""Confirmation that the API key was deleted"""


class DeleteKeysResponse(BaseModel):
    r"""API key deleted successfully"""

    DELETED: Annotated[
        Annotated[Literal[True], AfterValidator(validate_const(True))],
        pydantic.Field(alias="deleted"),
    ] = True
    r"""Confirmation that the API key was deleted"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ._schema14 import Schema14, Schema14TypedDict
from openrouter.types import BaseModel
from typing import Any, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


PromptTypedDict = TypeAliasType("PromptTypedDict", Union[float, str, Any])


Prompt = TypeAliasType("Prompt", Union[float, str, Any])


CompletionTypedDict = TypeAliasType("CompletionTypedDict", Union[float, str, Any])


Completion = TypeAliasType("Completion", Union[float, str, Any])


class Schema10TypedDict(TypedDict):
    prompt: NotRequired[PromptTypedDict]
    completion: NotRequired[CompletionTypedDict]
    image: NotRequired[Schema14TypedDict]
    audio: NotRequired[Schema14TypedDict]
    request: NotRequired[Schema14TypedDict]


class Schema10(BaseModel):
    prompt: Optional[Prompt] = None

    completion: Optional[Completion] = None

    image: Optional[Schema14] = None

    audio: Optional[Schema14] = None

    request: Optional[Schema14] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Any, Union
from typing_extensions import TypeAliasType


Schema14TypedDict = TypeAliasType("Schema14TypedDict", Union[float, str, Any])


Schema14 = TypeAliasType("Schema14", Union[float, str, Any])



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ._schema10 import Schema10, Schema10TypedDict
from ._schema17 import Schema17, Schema17TypedDict
from ._schema5 import Schema5, Schema5TypedDict
from .chatstreamoptions import ChatStreamOptions, ChatStreamOptionsTypedDict
from .message import Message, MessageTypedDict
from .providersortunion import ProviderSortUnion, ProviderSortUnionTypedDict
from .reasoningsummaryverbosity import ReasoningSummaryVerbosity
from .responseformatjsonschema import (
    ResponseFormatJSONSchema,
    ResponseFormatJSONSchemaTypedDict,
)
from .responseformattextgrammar import (
    ResponseFormatTextGrammar,
    ResponseFormatTextGrammarTypedDict,
)
from .tooldefinitionjson import ToolDefinitionJSON, ToolDefinitionJSONTypedDict
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from openrouter.utils import get_discriminator, validate_const, validate_open_enum
import pydantic
from pydantic import Discriminator, Tag, model_serializer
from pydantic.functional_validators import AfterValidator, PlainValidator
from typing import Any, Dict, List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


Schema3 = Union[
    Literal[
        "deny",
        "allow",
    ],
    UnrecognizedStr,
]


Schema8 = Union[
    Literal[
        "int4",
        "int8",
        "fp4",
        "fp6",
        "fp8",
        "fp16",
        "bf16",
        "fp32",
        "unknown",
    ],
    UnrecognizedStr,
]


class Schema15TypedDict(TypedDict):
    p50: NotRequired[Nullable[float]]
    p75: NotRequired[Nullable[float]]
    p90: NotRequired[Nullable[float]]
    p99: NotRequired[Nullable[float]]


class Schema15(BaseModel):
    p50: OptionalNullable[float] = UNSET

    p75: OptionalNullable[float] = UNSET

    p90: OptionalNullable[float] = UNSET

    p99: OptionalNullable[float] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["p50", "p75", "p90", "p99"]
        nullable_fields = ["p50", "p75", "p90", "p99"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


Schema15UnionTypedDict = TypeAliasType(
    "Schema15UnionTypedDict", Union[Schema15TypedDict, float]
)


Schema15Union = TypeAliasType("Schema15Union", Union[Schema15, float])


class Schema0TypedDict(TypedDict):
    allow_fallbacks: NotRequired[Nullable[bool]]
    require_parameters: NotRequired[Nullable[bool]]
    data_collection: NotRequired[Nullable[Schema3]]
    zdr: NotRequired[Nullable[bool]]
    enforce_distillable_text: NotRequired[Nullable[bool]]
    order: NotRequired[Nullable[List[Schema5TypedDict]]]
    only: NotRequired[Nullable[List[Schema5TypedDict]]]
    ignore: NotRequired[Nullable[List[Schema5TypedDict]]]
    quantizations: NotRequired[Nullable[List[Schema8]]]
    sort: NotRequired[Nullable[ProviderSortUnionTypedDict]]
    max_price: NotRequired[Schema10TypedDict]
    preferred_min_throughput: NotRequired[Nullable[Schema15UnionTypedDict]]
    preferred_max_latency: NotRequired[Nullable[Schema15UnionTypedDict]]


class Schema0(BaseModel):
    allow_fallbacks: OptionalNullable[bool] = UNSET

    require_parameters: OptionalNullable[bool] = UNSET

    data_collection: Annotated[
        OptionalNullable[Schema3], PlainValidator(validate_open_enum(False))
    ] = UNSET

    zdr: OptionalNullable[bool] = UNSET

    enforce_distillable_text: OptionalNullable[bool] = UNSET

    order: OptionalNullable[List[Schema5]] = UNSET

    only: OptionalNullable[List[Schema5]] = UNSET

    ignore: OptionalNullable[List[Schema5]] = UNSET

    quantizations: OptionalNullable[
        List[Annotated[Schema8, PlainValidator(validate_open_enum(False))]]
    ] = UNSET

    sort: OptionalNullable[ProviderSortUnion] = UNSET

    max_price: Optional[Schema10] = None

    preferred_min_throughput: OptionalNullable[Schema15Union] = UNSET

    preferred_max_latency: OptionalNullable[Schema15Union] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "allow_fallbacks",
            "require_parameters",
            "data_collection",
            "zdr",
            "enforce_distillable_text",
            "order",
            "only",
            "ignore",
            "quantizations",
            "sort",
            "max_price",
            "preferred_min_throughput",
            "preferred_max_latency",
        ]
        nullable_fields = [
            "allow_fallbacks",
            "require_parameters",
            "data_collection",
            "zdr",
            "enforce_distillable_text",
            "order",
            "only",
            "ignore",
            "quantizations",
            "sort",
            "preferred_min_throughput",
            "preferred_max_latency",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


Route = Union[
    Literal[
        "fallback",
        "sort",
    ],
    UnrecognizedStr,
]


Effort = Union[
    Literal[
        "xhigh",
        "high",
        "medium",
        "low",
        "minimal",
        "none",
    ],
    UnrecognizedStr,
]


class ReasoningTypedDict(TypedDict):
    effort: NotRequired[Nullable[Effort]]
    summary: NotRequired[Nullable[ReasoningSummaryVerbosity]]


class Reasoning(BaseModel):
    effort: Annotated[
        OptionalNullable[Effort], PlainValidator(validate_open_enum(False))
    ] = UNSET

    summary: Annotated[
        OptionalNullable[ReasoningSummaryVerbosity],
        PlainValidator(validate_open_enum(False)),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["effort", "summary"]
        nullable_fields = ["effort", "summary"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ResponseFormatPythonTypedDict(TypedDict):
    type: Literal["python"]


class ResponseFormatPython(BaseModel):
    TYPE: Annotated[
        Annotated[Literal["python"], AfterValidator(validate_const("python"))],
        pydantic.Field(alias="type"),
    ] = "python"


class ResponseFormatJSONObjectTypedDict(TypedDict):
    type: Literal["json_object"]


class ResponseFormatJSONObject(BaseModel):
    TYPE: Annotated[
        Annotated[
            Literal["json_object"], AfterValidator(validate_const("json_object"))
        ],
        pydantic.Field(alias="type"),
    ] = "json_object"


class ResponseFormatTextTypedDict(TypedDict):
    type: Literal["text"]


class ResponseFormatText(BaseModel):
    TYPE: Annotated[
        Annotated[Literal["text"], AfterValidator(validate_const("text"))],
        pydantic.Field(alias="type"),
    ] = "text"


ResponseFormatTypedDict = TypeAliasType(
    "ResponseFormatTypedDict",
    Union[
        ResponseFormatTextTypedDict,
        ResponseFormatJSONObjectTypedDict,
        ResponseFormatPythonTypedDict,
        ResponseFormatJSONSchemaTypedDict,
        ResponseFormatTextGrammarTypedDict,
    ],
)


ResponseFormat = Annotated[
    Union[
        Annotated[ResponseFormatText, Tag("text")],
        Annotated[ResponseFormatJSONObject, Tag("json_object")],
        Annotated[ResponseFormatJSONSchema, Tag("json_schema")],
        Annotated[ResponseFormatTextGrammar, Tag("grammar")],
        Annotated[ResponseFormatPython, Tag("python")],
    ],
    Discriminator(lambda m: get_discriminator(m, "type", "type")),
]


StopTypedDict = TypeAliasType("StopTypedDict", Union[str, List[str]])


Stop = TypeAliasType("Stop", Union[str, List[str]])


class DebugTypedDict(TypedDict):
    echo_upstream_body: NotRequired[bool]


class Debug(BaseModel):
    echo_upstream_body: Optional[bool] = None


ChatGenerationParamsImageConfigTypedDict = TypeAliasType(
    "ChatGenerationParamsImageConfigTypedDict", Union[str, float, List[Any]]
)


ChatGenerationParamsImageConfig = TypeAliasType(
    "ChatGenerationParamsImageConfig", Union[str, float, List[Any]]
)


Modality = Union[
    Literal[
        "text",
        "image",
    ],
    UnrecognizedStr,
]


class ChatGenerationParamsTypedDict(TypedDict):
    messages: List[MessageTypedDict]
    provider: NotRequired[Nullable[Schema0TypedDict]]
    plugins: NotRequired[List[Schema17TypedDict]]
    route: NotRequired[Nullable[Route]]
    user: NotRequired[str]
    session_id: NotRequired[str]
    model: NotRequired[str]
    models: NotRequired[List[str]]
    frequency_penalty: NotRequired[Nullable[float]]
    logit_bias: NotRequired[Nullable[Dict[str, float]]]
    logprobs: NotRequired[Nullable[bool]]
    top_logprobs: NotRequired[Nullable[float]]
    max_completion_tokens: NotRequired[Nullable[float]]
    max_tokens: NotRequired[Nullable[float]]
    metadata: NotRequired[Dict[str, str]]
    presence_penalty: NotRequired[Nullable[float]]
    reasoning: NotRequired[ReasoningTypedDict]
    response_format: NotRequired[ResponseFormatTypedDict]
    seed: NotRequired[Nullable[int]]
    stop: NotRequired[Nullable[StopTypedDict]]
    stream: NotRequired[bool]
    stream_options: NotRequired[Nullable[ChatStreamOptionsTypedDict]]
    temperature: NotRequired[Nullable[float]]
    tool_choice: NotRequired[Any]
    tools: NotRequired[List[ToolDefinitionJSONTypedDict]]
    top_p: NotRequired[Nullable[float]]
    debug: NotRequired[DebugTypedDict]
    image_config: NotRequired[Dict[str, ChatGenerationParamsImageConfigTypedDict]]
    modalities: NotRequired[List[Modality]]


class ChatGenerationParams(BaseModel):
    messages: List[Message]

    provider: OptionalNullable[Schema0] = UNSET

    plugins: Optional[List[Schema17]] = None

    route: Annotated[
        OptionalNullable[Route], PlainValidator(validate_open_enum(False))
    ] = UNSET

    user: Optional[str] = None

    session_id: Optional[str] = None

    model: Optional[str] = None

    models: Optional[List[str]] = None

    frequency_penalty: OptionalNullable[float] = UNSET

    logit_bias: OptionalNullable[Dict[str, float]] = UNSET

    logprobs: OptionalNullable[bool] = UNSET

    top_logprobs: OptionalNullable[float] = UNSET

    max_completion_tokens: OptionalNullable[float] = UNSET

    max_tokens: OptionalNullable[float] = UNSET

    metadata: Optional[Dict[str, str]] = None

    presence_penalty: OptionalNullable[float] = UNSET

    reasoning: Optional[Reasoning] = None

    response_format: Optional[ResponseFormat] = None

    seed: OptionalNullable[int] = UNSET

    stop: OptionalNullable[Stop] = UNSET

    stream: Optional[bool] = False

    stream_options: OptionalNullable[ChatStreamOptions] = UNSET

    temperature: OptionalNullable[float] = UNSET

    tool_choice: Optional[Any] = None

    tools: Optional[List[ToolDefinitionJSON]] = None

    top_p: OptionalNullable[float] = UNSET

    debug: Optional[Debug] = None

    image_config: Optional[Dict[str, ChatGenerationParamsImageConfig]] = None

    modalities: Optional[
        List[Annotated[Modality, PlainValidator(validate_open_enum(False))]]
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "provider",
            "plugins",
            "route",
            "user",
            "session_id",
            "model",
            "models",
            "frequency_penalty",
            "logit_bias",
            "logprobs",
            "top_logprobs",
            "max_completion_tokens",
            "max_tokens",
            "metadata",
            "presence_penalty",
            "reasoning",
            "response_format",
            "seed",
            "stop",
            "stream",
            "stream_options",
            "temperature",
            "tool_choice",
            "tools",
            "top_p",
            "debug",
            "image_config",
            "modalities",
        ]
        nullable_fields = [
            "provider",
            "route",
            "frequency_penalty",
            "logit_bias",
            "logprobs",
            "top_logprobs",
            "max_completion_tokens",
            "max_tokens",
            "presence_penalty",
            "seed",
            "stop",
            "stream_options",
            "temperature",
            "top_p",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from openrouter.components import chaterror as components_chaterror
from openrouter.errors import OpenRouterError
from openrouter.types import BaseModel
from typing import Optional


class ChatErrorData(BaseModel):
    error: components_chaterror.ChatErrorError


@dataclass(unsafe_hash=True)
class ChatError(OpenRouterError):
    data: ChatErrorData = field(hash=False)

    def __init__(
        self,
        data: ChatErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
